@@ -24,7 +24,7 @@
 # 3. This notice may not be removed or altered from any source
 #    distribution.
 #
-# $Id: item-manager.rb 624 2005-09-06 21:23:03Z svn $
+# $Id: item-manager.rb 646 2005-09-08 01:23:14Z svn $
 ###############################################################################
 
 require 'erb'
@@ -72,13 +72,13 @@ class ItemManager
     ERB.new(File.read(tmpl_path))
   end
 
-  def remove_page(file_path)
+  def remove_page(file_path, page)
     item_list = load_item_list
 
     begin
       item_list.remove(file_path)
 
-      return view_page(1)
+      return view_page(page)
     rescue Exception
       return error_page($!.message)
     end
