@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: CharCodeConverter.h 466 2005-07-17 05:11:07Z svn $
+ * $Id: CharCodeConverter.h 535 2005-08-30 20:15:17Z svn $
  *****************************************************************************/
 
 #ifndef CHARCODECONVERTER_H
@@ -49,7 +49,7 @@ public:
     static const char DEFAULT_CODE[];
 
     static const char *convert(apr_pool_t *pool, const char *str,
-                               const char *pat);
+                               const unsigned char *pat);
     static const char *convert(apr_pool_t *pool, const char *str,
                                const char *from, const char *to);
 
