@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: FileWriter.h 466 2005-07-17 05:11:07Z svn $
+ * $Id: FileWriter.h 469 2005-07-19 00:23:53Z svn $
  *****************************************************************************/
 
 #ifndef FILEWRITER_H
@@ -54,14 +54,15 @@ protected:
     {
         return pool_;
     }
+
     apr_file_t *get_fd()
     {
         return fd_;
     }
 
 private:
-    apr_pool_t * const pool_;
-    apr_file_t * const fd_;
+    apr_pool_t *pool_;
+    apr_file_t *fd_;
     bool is_closed_;
 
     FileWriter(const FileWriter &);
