@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MmapFileWriter.h 466 2005-07-17 05:11:07Z svn $
+ * $Id: MmapFileWriter.h 469 2005-07-19 00:23:53Z svn $
  *****************************************************************************/
 
 #ifndef MMAPFILEWRITER_H
@@ -63,7 +63,7 @@ private:
 
     apr_mmap_t *file_map_;
     apr_size_t size_factor_;
-    apr_size_t block_size_;
+    const apr_size_t block_size_;
     apr_size_t offset_;
     bool is_closed_;
 
