@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PlainConverter.h 506 2005-08-23 22:04:02Z svn $
+ * $Id: PlainConverter.h 516 2005-08-26 07:10:16Z svn $
  *****************************************************************************/
 
 #ifndef PLAINCONVERTER_H
@@ -41,6 +41,8 @@
 
 using namespace std;
 
+class UploadItemReader;
+
 /**
  * @brief åץɥƥ̾ΥեѴ륯饹
  */
@@ -48,15 +50,20 @@ class PlainConverter
 {
 public:
     PlainConverter(apr_pool_t *pool);
-    void convert_dir(const char *upload_dir, const char *plain_dir,
-                     const char *code, bool is_quiet=true);
-    void convert_file(const char *upload_file, const char *plain_dir,
-                      const char *code, bool is_quiet=true);
+    void convert(const char *src_path, const char *plain_dir_path,
+                 const char *code, bool is_quiet);
+    void convert_dir(const char *upload_dir_path, const char *plain_dir_path,
+                     const char *code, bool is_quiet);
+    void convert_file(const char *upload_file_path, const char *plain_dir_path,
+                      const char *code, bool is_quiet);
 
 private:
     PlainConverter(const PlainConverter&);
     PlainConverter &operator=(const PlainConverter&);
 
+    void convert_file(UploadItemReader &reader,
+                      const char *upload_file_name, const char *plain_dir_path,
+                      const char *code, bool is_quiet);
     const char *create_file_path(const char *plain_dir, const char *plain_name,
                                  const char *code);
     apr_filetype_e get_file_type(const char *path);
