@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: RFC1867Parser.h 598 2005-09-05 18:44:00Z svn $
+ * $Id: RFC1867Parser.h 638 2005-09-07 21:51:26Z svn $
  *****************************************************************************/
 
 #ifndef RFC1867PARSER_H
@@ -128,7 +128,8 @@ public:
                   apr_size_t max_item_num,
                   apr_size_t file_offset=0);
     query_map *parse(apr_pool_t *pool, request_rec *request,
-                     const char *content_type);
+                     const char *content_type, apr_size_t content_size,
+                     PostReader::progress *progress);
 
     static void clean_tmp_file(apr_pool_t *pool, query_map *qmap,
                                bool is_strict=false);
@@ -171,13 +172,13 @@ private:
         BinString buffer;
 
         Handle(apr_pool_t *pool, request_rec *request, const char *boundary,
-               query_map *query_map)
+               query_map *query_map, PostReader::progress *progress)
             : pool(pool),
               boundary(boundary),
               request(request),
               boundary_len(strlen(boundary)),
               qmap(query_map),
-              reader(READ_BLOCK_SIZE, request),
+              reader(READ_BLOCK_SIZE, request, progress),
               buffer(READ_BLOCK_SIZE*3) // 3 ʾ夸ʤȤޤ
         {
 
