@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateLexer.h 469 2005-07-19 00:23:53Z svn $
+ * $Id: TemplateLexer.h 543 2005-08-31 17:25:22Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATELEXER_H
@@ -196,7 +196,7 @@ private:
 #endif
 
     apr_pool_t *pool_;
-    apr_pool_t *temp_pool_;
+    apr_pool_t *tmp_pool_;
 
     handle handle_;
     token_vector tvector_;
