@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.h 479 2005-07-23 12:53:27Z svn $
+ * $Id: UploadItem.h 547 2005-08-31 19:53:30Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADITEM_H
@@ -65,15 +65,20 @@ public:
     static const char CODE_PAT_PARAM[];
 
     typedef struct Header {
-        char                identifier[(sizeof(PACKAGE_NAME)/4 + 1)*4];
-        char                version[MAX_VERSION_LENGTH];
-        apr_size_t          file_size;
-        apr_time_t          time;
-        char                file_mime[MAX_FILE_MIME_LENGTH];
-        char                file_name[MAX_FILE_NAME_LENGTH];
-        char                remove_pass[MAX_REMOVE_PASS_LENGTH];
-        char                download_pass[MAX_DOWNLOAD_PASS_LENGTH];
-        char                comment[MAX_COMMENT_LENGTH];
+        union {
+            struct {
+                char        identifier[(sizeof(PACKAGE_NAME)/4 + 1)*4];
+                char        version[MAX_VERSION_LENGTH];
+                apr_size_t  file_size;
+                apr_time_t  time;
+                char        file_mime[MAX_FILE_MIME_LENGTH];
+                char        file_name[MAX_FILE_NAME_LENGTH];
+                char        remove_pass[MAX_REMOVE_PASS_LENGTH];
+                char        download_pass[MAX_DOWNLOAD_PASS_LENGTH];
+                char        comment[MAX_COMMENT_LENGTH];
+            };
+            char            dummy[ITEM_HEADER_SIZE];
+        };
     } header;
 
     UploadItem(apr_pool_t *pool, const char *file_path, header *header);
