@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.h 550 2005-09-01 07:23:16Z svn $
+ * $Id: UploadItemList.h 570 2005-09-02 21:21:36Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADITEMLIST_H
@@ -33,6 +33,9 @@
 #include "UploadItem.h"
 #include "UploadItemReader.h"
 #include "TemplateExecutor.h"
+#ifdef MAKE_THUMBNAIL
+#include "ThumbnailWriter.h"
+#endif
 
 #include "apr_pools.h"
 
@@ -67,7 +70,7 @@ public:
     apr_uint64_t get_total_file_size() const;
     apr_size_t get_thumb_size() const;
     apr_time_t get_mtime() const;
-    void set_mtime();
+    void update_mtime();
     bool is_need_update() const;
     void remove(const char *file_path, const char *password);
     TemplateExecutor::variable *to_varray(apr_pool_t *pool,
@@ -112,19 +115,6 @@ private:
     typedef list<string> thumb_list;
     typedef thumb_list::const_iterator thumb_iterator;
 
-    apr_pool_t *pool_;
-    apr_pool_t *data_pool_;
-    const char *file_dir_;
-    const char *thumb_dir_;
-    const apr_size_t total_number_limit_;
-    const apr_uint64_t total_size_limit_;
-
-    UploadItemReader reader;
-    apr_uint64_t total_size_;
-    item_list ilist_;
-    thumb_list tlist_;
-    apr_time_t mtime_;
-
     UploadItemList(const UploadItemList&);
     UploadItemList &operator=(const UploadItemList&);
 
@@ -156,6 +146,22 @@ private:
     void write_cache();
     void write_path_cache(apr_pool_t *tmp_pool);
     void write_header_cache(apr_pool_t *tmp_pool);
+
+    apr_pool_t *pool_;
+    apr_pool_t *data_pool_;
+    const char *file_dir_;
+    const char *thumb_dir_;
+    const apr_size_t total_number_limit_;
+    const apr_uint64_t total_size_limit_;
+
+    UploadItemReader reader_;
+#ifdef MAKE_THUMBNAIL
+    ThumbnailWriter twriter_;
+#endif
+    apr_uint64_t total_size_;
+    item_list ilist_;
+    thumb_list tlist_;
+    apr_time_t mtime_;
 };
 
 #endif
