@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemWriter.h 466 2005-07-17 05:11:07Z svn $
+ * $Id: UploadItemWriter.h 469 2005-07-19 00:23:53Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADITEMWRITER_H
@@ -60,7 +60,7 @@ class UploadItemWriter
     void write_date(UploadItem::header *header, const char *file_path, const char *tmp_path);
     static const char *create_file_name(apr_pool_t *pool, const char *file_dir);
 
-    apr_pool_t * const pool_;
+    apr_pool_t *pool_;
     const char * const file_dir_;
 };
 
