@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.h 573 2005-09-03 07:50:04Z svn $
+ * $Id: UploaderConfig.h 643 2005-09-07 23:36:20Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADERCONFIG_H
@@ -92,6 +92,7 @@ public:
     void finalize();
 
     page_template *get_view_template(apr_pool_t *pool);
+    page_template *get_progress_template(apr_pool_t *pool);
     page_template *get_download_template(apr_pool_t *pool);
     page_template *get_thumb_template(apr_pool_t *pool);
     page_template *get_error_template(apr_pool_t *pool);
@@ -110,6 +111,7 @@ public:
     const char *tmp_dir;
     const char *magick_dir;
     const char *view_tmpl_path;
+    const char *progress_tmpl_path;
     const char *download_tmpl_path;
     const char *thumb_tmpl_path;
     const char *error_tmpl_path;
@@ -152,6 +154,8 @@ private:
     apr_pool_t *pool_;
     page_template *view_tmpl_;
     apr_pool_t *view_tmpl_pool_;
+    page_template *progress_tmpl_;
+    apr_pool_t *progress_tmpl_pool_;
     page_template *download_tmpl_;
     apr_pool_t *download_tmpl_pool_;
     page_template *thumb_tmpl_;
