@@ -24,10 +24,11 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BasicFileWriter.cpp 471 2005-07-21 13:46:09Z svn $
+ * $Id: BasicFileWriter.cpp 537 2005-08-30 21:18:51Z svn $
  *****************************************************************************/
 
 #include "BasicFileWriter.h"
+#include "Misc.h"
 
 #include "apr_mmap.h"
 
@@ -51,13 +52,9 @@ void BasicFileWriter::write(const void *buf, apr_size_t size)
 {
     apr_size_t write_size = size;
 
-    if (apr_file_write(get_fd(), buf, &write_size) != APR_SUCCESS) {
+    if (UNLIKELY(apr_file_write_full(get_fd(), buf, write_size, &write_size) != APR_SUCCESS)) {
         throw "ե write ˼Ԥޤ";
     }
-
-    if (write_size != size) {
-        throw "ե write ˹ԤޤǤ";
-    }
 }
 
 
