@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: FileWriter.cpp 436 2005-07-08 05:36:22Z svn $
+ * $Id: FileWriter.cpp 538 2005-08-30 22:50:49Z svn $
  *****************************************************************************/
 
 #include "FileWriter.h"
@@ -37,9 +37,10 @@
 /******************************************************************************
  * public ᥽å
  *****************************************************************************/
-FileWriter::FileWriter(apr_pool_t *pool, apr_file_t *fd) : pool_(pool),
-                                                           fd_(fd),
-                                                           is_closed_(false)
+FileWriter::FileWriter(apr_pool_t *pool, apr_file_t *fd)
+    : pool_(pool),
+      fd_(fd),
+      is_closed_(false)
 {
 
 }
