@@ -24,10 +24,11 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MmapFileWriter.cpp 468 2005-07-18 10:11:42Z svn $
+ * $Id: MmapFileWriter.cpp 548 2005-08-31 20:29:04Z svn $
  *****************************************************************************/
 
 #include "MmapFileWriter.h"
+#include "Misc.h"
 
 #include "apr_mmap.h"
 #define APR_WANT_MEMFUNC
@@ -70,7 +71,7 @@ void MmapFileWriter::write(const void *buf, apr_size_t size)
     const char *data;
     apr_size_t write_size;
 
-    data = reinterpret_cast<const char *>(buf);
+    data = static_cast<const char *>(buf);
 
     while (size > 0) {
         write_size = (size > block_size_) ? block_size_ : size;
@@ -79,7 +80,7 @@ void MmapFileWriter::write(const void *buf, apr_size_t size)
             if (offset_ != block_size_) {
                 write_size = block_size_ - offset_;
 
-                memcpy(reinterpret_cast<char *>(file_map_->mm)+offset_, data, write_size);
+                memcpy(static_cast<char *>(file_map_->mm)+offset_, data, write_size);
                 data += write_size;
                 size -= write_size;
             }
@@ -88,7 +89,7 @@ void MmapFileWriter::write(const void *buf, apr_size_t size)
             continue;
         }
 
-        memcpy(reinterpret_cast<char *>(file_map_->mm)+offset_, data, write_size);
+        memcpy(static_cast<char *>(file_map_->mm)+offset_, data, write_size);
 
         data += write_size;
         offset_ += write_size;
@@ -148,7 +149,7 @@ void MmapFileWriter::expand()
     }
 
     if (apr_mmap_create(&file_map_, get_fd(), pseudo_size-block_size_,
-                        block_size_, APR_MMAP_WRITE, get_pool()) != APR_SUCCESS) {
+                        block_size_, APR_MMAP_READ|APR_MMAP_WRITE, get_pool()) != APR_SUCCESS) {
         throw "ե map ˼Ԥޤ";
     }
 
