@@ -32,6 +32,7 @@
 
 #include "RssView.h"
 #include "TemplateVariableCreator.h"
+#include "Misc.h"
 
 #include "http_protocol.h"
 
@@ -98,7 +99,7 @@ void RssView::exec(apr_pool_t *pool, request_rec *request, const char *base_url,
 /******************************************************************************
  * private ᥽å
  *****************************************************************************/
-inline void RssView::print(handle *h, item_info *item)
+void RssView::print(handle *h, item_info *item)
 {
     print(h, "<item rdf:about=\"");
     print(h, h->base_url);
@@ -127,7 +128,7 @@ inline void RssView::print(handle *h, item_info *item)
     print(h, "</item>");
 }
 
-inline void RssView::print(handle *h, const char *str)
+void RssView::print(handle *h, const char *str)
 {
 #ifdef DEBUG_RssView
     cout << str;
@@ -142,7 +143,7 @@ const char *RssView::time_str(apr_pool_t *pool, apr_time_t time)
     char *time_str;
     apr_size_t size;
 
-    time_str = reinterpret_cast<char *>(apr_palloc(pool, sizeof(char)*MAX_TIME_LENGTH));
+    APR_PALLOC(time_str, char *, pool, sizeof(char)*MAX_TIME_LENGTH);
 
     if (time_str == NULL) {
         throw "ɽΤΥݤ˼Ԥޤ";
