@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateExecutor.cpp 480 2005-07-23 14:46:26Z svn $
+ * $Id: TemplateExecutor.cpp 535 2005-08-30 20:15:17Z svn $
  *****************************************************************************/
 
 #include "TemplateExecutor.h"
@@ -394,7 +394,7 @@ int TemplateExecutor::calc_i_val(handle *h, node *node)
     }
 }
 
-inline int TemplateExecutor::calc_i_val(TemplateExecutor::variable* var)
+int TemplateExecutor::calc_i_val(TemplateExecutor::variable* var)
 {
     switch (var->type) {
     case SCALAR:
@@ -412,7 +412,7 @@ inline int TemplateExecutor::calc_i_val(TemplateExecutor::variable* var)
     }
 }
 
-inline TemplateExecutor::variable *TemplateExecutor::get_var(handle *h, node *node)
+TemplateExecutor::variable *TemplateExecutor::get_var(handle *h, node *node)
 {
     // ϢޤλͤϤӤߤ硼
 
@@ -446,7 +446,7 @@ inline TemplateExecutor::variable *TemplateExecutor::get_var(handle *h, node *no
                 throw "Ϣɬפʾˤ¾ѿꤵƤޤ";
             }
             key = node->branch.right->branch.right->s_val;
-            var = reinterpret_cast<variable *>(apr_hash_get(var->h_val, key,
+            var = static_cast<variable *>(apr_hash_get(var->h_val, key,
                                                             APR_HASH_KEY_STRING));
         }
         break;
@@ -460,7 +460,7 @@ inline TemplateExecutor::variable *TemplateExecutor::get_var(handle *h, node *no
 
         key = h->imap->at(node->branch.right->i_val);
 
-        var = reinterpret_cast<variable *>(apr_hash_get(var->h_val, key,
+        var = static_cast<variable *>(apr_hash_get(var->h_val, key,
                                                         APR_HASH_KEY_STRING));
         break;
     default:
@@ -476,13 +476,12 @@ inline TemplateExecutor::variable *TemplateExecutor::get_var(handle *h, node *no
     return var;
 }
 
-inline TemplateExecutor::variable *TemplateExecutor::create_variable(handle *h,
+TemplateExecutor::variable *TemplateExecutor::create_variable(handle *h,
                                                                      variable_type type)
 {
     if (h->variable_pool == h->variable_pool_end) {
-        h->variable_pool
-            = reinterpret_cast<variable *>(apr_palloc(h->pool,
-                                                      sizeof(variable)*VARIABLE_POOL_NUM));
+        APR_PALLOC(h->variable_pool, variable *, h->pool, sizeof(variable)*VARIABLE_POOL_NUM);
+
         h->variable_pool_end = h->variable_pool + VARIABLE_POOL_NUM;
     }
 
@@ -492,13 +491,12 @@ inline TemplateExecutor::variable *TemplateExecutor::create_variable(handle *h,
     return variable;
 }
 
-inline TemplateExecutor::scalar *TemplateExecutor::create_scalar(handle *h,
+TemplateExecutor::scalar *TemplateExecutor::create_scalar(handle *h,
                                                                  scalar_type type)
 {
     if (h->scalar_pool == h->scalar_pool_end) {
-        h->scalar_pool
-            = reinterpret_cast<scalar *>(apr_palloc(h->pool,
-                                                      sizeof(scalar)*SCALAR_POOL_NUM));
+        APR_PALLOC(h->scalar_pool, scalar *, h->pool, sizeof(scalar)*SCALAR_POOL_NUM);
+
         h->scalar_pool_end = h->scalar_pool + SCALAR_POOL_NUM;
     }
 
@@ -508,7 +506,7 @@ inline TemplateExecutor::scalar *TemplateExecutor::create_scalar(handle *h,
     return scalar;
 }
 
-inline void TemplateExecutor::print(handle *h, int i_val)
+void TemplateExecutor::print(handle *h, int i_val)
 {
 #ifdef DEBUG_TEMPLATE
     cout << i_val;
@@ -517,7 +515,7 @@ inline void TemplateExecutor::print(handle *h, int i_val)
 #endif
 }
 
-inline void TemplateExecutor::print(handle *h, const char *s_val)
+void TemplateExecutor::print(handle *h, const char *s_val)
 {
 #ifdef DEBUG_TEMPLATE
     cout << s_val;
@@ -578,14 +576,14 @@ int main(int argc, const char * const *argv)
         }
 
         if (apr_mmap_create(&file_map, fd, 0,
-                            reinterpret_cast<apr_size_t>(info.size), APR_MMAP_READ,
+                            static_cast<apr_size_t>(info.size), APR_MMAP_READ,
                             pool) != APR_SUCCESS) {
             throw "ե mmap ˼Ԥޤ";
         }
 
         TemplateLexer lexer(pool,
-                            reinterpret_cast<const char *>(file_map->mm),
-                            reinterpret_cast<apr_size_t>(info.size));
+                            static_cast<const char *>(file_map->mm),
+                            static_cast<apr_size_t>(info.size));
         TemplateParser parser(pool);
         node = parser.parse(lexer.get_token_list(), lexer.get_ident_map());
 
