@@ -24,11 +24,12 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateLexer.cpp 483 2005-07-23 20:52:16Z svn $
+ * $Id: TemplateLexer.cpp 543 2005-08-31 17:25:22Z svn $
  *****************************************************************************/
 
 #include "TemplateLexer.h"
 #include "Auxiliary.h"
+#include "Misc.h"
 
 #include "apr_strings.h"
 #define APR_WANT_STRFUNC
@@ -139,7 +140,7 @@ TemplateLexer::TemplateLexer(apr_pool_t *pool, const char *input, apr_size_t len
       token_pool_end_(NULL),
       is_done_(false)
 {
-    if (apr_pool_create(&temp_pool_, pool) != APR_SUCCESS) {
+    if (apr_pool_create(&tmp_pool_, pool) != APR_SUCCESS) {
         throw "γݤ˼Ԥޤ";
     }
 
@@ -148,7 +149,7 @@ TemplateLexer::TemplateLexer(apr_pool_t *pool, const char *input, apr_size_t len
 
 TemplateLexer::~TemplateLexer()
 {
-    apr_pool_clear(temp_pool_);
+    apr_pool_destroy(tmp_pool_);
 }
 
 TemplateLexer::token_vector *TemplateLexer::get_token_list()
@@ -316,8 +317,7 @@ TemplateLexer::token *TemplateLexer::get_token(handle *h,
         }
         token->type = STRING;
 
-        token->s_val = reinterpret_cast<char *>(apr_palloc(temp_pool_,
-                                                      sizeof(char)*(h->input-start)));
+        APR_PALLOC(token->s_val, char *, pool_, sizeof(char)*(h->input-start+1));
 
         s_value = const_cast<char *>(token->s_val);
         while (start != h->input) {
@@ -327,7 +327,7 @@ TemplateLexer::token *TemplateLexer::get_token(handle *h,
                 *(s_value++) = *(start++);
             }
         }
-        *(s_value) = '\0';
+        *s_value = '\0';
 
         h->input++;
         break;
@@ -404,8 +404,8 @@ TemplateLexer::token *TemplateLexer::read_tmpl_string(handle *h)
     const char *var_end;
     token *token;
 
-    str_end = reinterpret_cast<char *>(memmem(h->input, h->input_end-h->input,
-                                              CODE_BEGIN_STR, strlen(CODE_BEGIN_STR)));
+    str_end = static_cast<char *>(memmem(h->input, h->input_end-h->input,
+                                         CODE_BEGIN_STR, strlen(CODE_BEGIN_STR)));
 
     if (str_end == NULL) {
         is_code_begin = false;
@@ -502,19 +502,18 @@ apr_size_t TemplateLexer::get_imap_id(const char * const start, apr_size_t lengt
     }
 
     if (id == imap_.size()) {
-        imap_.push_back(reinterpret_cast<const char *>(apr_pstrndup(pool_, start,
+        imap_.push_back(static_cast<const char *>(apr_pstrndup(pool_, start,
                                                                     length)));
     }
 
     return id;
 }
 
-inline TemplateLexer::token *TemplateLexer::create_token(token_type type)
+TemplateLexer::token *TemplateLexer::create_token(token_type type)
 {
     if (token_pool_ == token_pool_end_) {
-        token_pool_
-            = reinterpret_cast<token *>(apr_palloc(temp_pool_,
-                                                   sizeof(token)*TOKEN_POOL_NUM));
+        APR_PALLOC(token_pool_, token *, tmp_pool_, sizeof(token)*TOKEN_POOL_NUM);
+
         token_pool_end_ = token_pool_ + TOKEN_POOL_NUM;
     }
 
@@ -567,14 +566,14 @@ int main(int argc, const char * const *argv)
         }
 
         if (apr_mmap_create(&file_map, fd, 0,
-                            reinterpret_cast<apr_size_t>(info.size), APR_MMAP_READ,
+                            static_cast<apr_size_t>(info.size), APR_MMAP_READ,
                             pool) != APR_SUCCESS) {
             throw "ե mmap ˼Ԥޤ";
         }
 
         TemplateLexer lexer(pool,
-                            reinterpret_cast<const char *>(file_map->mm),
-                            reinterpret_cast<apr_size_t>(info.size));
+                            static_cast<const char *>(file_map->mm),
+                            static_cast<apr_size_t>(info.size));
 
         tvector = lexer.get_token_list();
         imap = lexer.get_ident_map();
