@@ -24,10 +24,11 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateParser.cpp 468 2005-07-18 10:11:42Z svn $
+ * $Id: TemplateParser.cpp 535 2005-08-30 20:15:17Z svn $
  *****************************************************************************/
 
 #include "TemplateParser.h"
+#include "Misc.h"
 
 #include "apr_strings.h"
 
@@ -118,24 +119,24 @@ apr_size_t TemplateParser::print_node(node *node)
     if (node->id == 0) {
         node->id = id++;
     }
-    cout << "\"node_" << reinterpret_cast<unsigned int>(node->id) <<  "\" [" << endl;
+    cout << "\"node_" << static_cast<unsigned int>(node->id) <<  "\" [" << endl;
     cout << "    label = \"" << get_node_type(node) << " | <0>left | <1>center | <2>right\"" << endl;
     cout << "];" << endl;
 
     if (node->branch.left != NULL) {
-        branch_id = reinterpret_cast<unsigned int>(print_node(node->branch.left));
+        branch_id = static_cast<unsigned int>(print_node(node->branch.left));
 
-        cout << "\"node_" << reinterpret_cast<unsigned int>(node->id) << "\":0 -> \"node_" << branch_id << "\"" << endl;
+        cout << "\"node_" << static_cast<unsigned int>(node->id) << "\":0 -> \"node_" << branch_id << "\"" << endl;
     }
     if (node->branch.center != NULL) {
-        branch_id = reinterpret_cast<unsigned int>(print_node(node->branch.center));
+        branch_id = static_cast<unsigned int>(print_node(node->branch.center));
 
-        cout << "\"node_" << reinterpret_cast<unsigned int>(node->id) << "\":1 -> \"node_" << branch_id << "\"" << endl;
+        cout << "\"node_" << static_cast<unsigned int>(node->id) << "\":1 -> \"node_" << branch_id << "\"" << endl;
     }
     if (node->branch.right != NULL) {
-        branch_id = reinterpret_cast<unsigned int>(print_node(node->branch.right));
+        branch_id = static_cast<unsigned int>(print_node(node->branch.right));
 
-        cout << "\"node_" << reinterpret_cast<unsigned int>(node->id) << "\":2 -> \"node_" << branch_id << "\"" << endl;
+        cout << "\"node_" << static_cast<unsigned int>(node->id) << "\":2 -> \"node_" << branch_id << "\"" << endl;
     }
 
     return node->id;
@@ -171,7 +172,7 @@ TemplateParser::node *TemplateParser::parse_program(handle *h)
  * STMT_LIST  ::= STMT*
  * </pre>
  */
-inline TemplateParser::node *TemplateParser::parse_stmt_list(handle *h)
+TemplateParser::node *TemplateParser::parse_stmt_list(handle *h)
 {
     node *curr_node = NULL;
     node *left = NULL;
@@ -562,7 +563,7 @@ TemplateParser::node *TemplateParser::parse_expr_list(handle *h)
  * EXPR       ::= ASSIGN | COMPARE
  * </pre>
  */
-inline TemplateParser::node *TemplateParser::parse_expr(handle *h)
+TemplateParser::node *TemplateParser::parse_expr(handle *h)
 {
     if (h->token == h->token_end) {
         return NULL;
@@ -1011,12 +1012,11 @@ TemplateParser::node *TemplateParser::parse_variable__(handle *h)
     return node;
 }
 
-inline TemplateParser::node *TemplateParser::create_node(node_type type)
+TemplateParser::node *TemplateParser::create_node(node_type type)
 {
     if (node_pool_ == node_pool_end_) {
-        node_pool_
-            = reinterpret_cast<node *>(apr_pcalloc(pool_,
-                                                  sizeof(node)*NODE_POOL_NUM));
+        APR_PCALLOC(node_pool_, node *, pool_, sizeof(node)*NODE_POOL_NUM);
+
         node_pool_end_ = node_pool_ + NODE_POOL_NUM;
     }
 
@@ -1030,7 +1030,7 @@ inline TemplateParser::node *TemplateParser::create_node(node_type type)
     return node;
 }
 
-inline TemplateParser::node *TemplateParser::create_node(TemplateLexer::token_type type)
+TemplateParser::node *TemplateParser::create_node(TemplateLexer::token_type type)
 {
     node_type ntype;
 
@@ -1102,14 +1102,14 @@ int main(int argc, const char * const *argv)
         }
 
         if (apr_mmap_create(&file_map, fd, 0,
-                            reinterpret_cast<apr_size_t>(info.size), APR_MMAP_READ,
+                            static_cast<apr_size_t>(info.size), APR_MMAP_READ,
                             pool) != APR_SUCCESS) {
             throw "ե mmap ˼Ԥޤ";
         }
 
         TemplateLexer lexer(pool,
-                            reinterpret_cast<const char *>(file_map->mm),
-                            reinterpret_cast<apr_size_t>(info.size));
+                            static_cast<const char *>(file_map->mm),
+                            static_cast<apr_size_t>(info.size));
         TemplateParser parser(pool);
         node = parser.parse(lexer.get_token_list(), lexer.get_ident_map());
         TemplateParser::print_dot(node);
