@@ -24,11 +24,12 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateVariableCreator.cpp 468 2005-07-18 10:11:42Z svn $
+ * $Id: TemplateVariableCreator.cpp 532 2005-08-30 09:30:01Z svn $
  *****************************************************************************/
 
 #include "TemplateVariableCreator.h"
 #include "TemplateExecutor.h"
+#include "Misc.h"
 
 #include "apr_hash.h"
 
@@ -67,9 +68,9 @@ TemplateVariableCreator::variable *TemplateVariableCreator::create(apr_pool_t *p
 {
     variable *var;
 
-    var = reinterpret_cast<variable *>(apr_palloc(pool, sizeof(variable)));
+    APR_PALLOC(var, variable *, pool, sizeof(variable));
     var->type = TemplateExecutor::SCALAR;
-    var->s_val = reinterpret_cast<scalar *>(apr_palloc(pool, sizeof(scalar)));
+    APR_PALLOC(var->s_val, scalar *, pool, sizeof(scalar));
     var->s_val->type = TemplateExecutor::STRING;
     var->s_val->s_val = str;
 
@@ -80,7 +81,7 @@ TemplateVariableCreator::variable *TemplateVariableCreator::create(apr_pool_t *p
 {
     variable *var;
 
-    var = reinterpret_cast<variable *>(apr_palloc(pool, sizeof(variable)));
+    APR_PALLOC(var, variable *, pool, sizeof(variable));
     var->type = TemplateExecutor::HASH;
     var->h_val = hash;
 
@@ -91,7 +92,7 @@ TemplateVariableCreator::variable *TemplateVariableCreator::create(apr_pool_t *p
 {
     variable *var;
 
-    var = reinterpret_cast<variable *>(apr_palloc(pool, sizeof(variable)));
+    APR_PALLOC(var, variable *, pool, sizeof(variable));
     var->type = TemplateExecutor::ARRAY;
     var->a_val = array;
 
