@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ThumbnailWriter.cpp 570 2005-09-02 21:21:36Z svn $
+ * $Id: ThumbnailWriter.cpp 594 2005-09-05 16:38:21Z svn $
  *****************************************************************************/
 
 #include "ThumbnailWriter.h"
@@ -136,7 +136,7 @@ void *ThumbnailWriter::read(apr_pool_t *pool, const char *file_path, apr_size_t
 
     if (header->file_size > SIZE_LIMIT) {
         // ݤ㳰ꤲ㤤ޤ
-        throw "ե륵礭ޤ";
+        throw "ե뤬礭ޤ";
     }
 
     APR_PALLOC(buffer, void *, pool, header->file_size);
