@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.cpp 535 2005-08-30 20:15:17Z svn $
+ * $Id: UploadItem.cpp 563 2005-09-02 03:22:28Z svn $
  *****************************************************************************/
 
 #include "UploadItem.h"
@@ -168,6 +168,116 @@ void UploadItem::dump_header(header *header)
 }
 #endif
 
+
+/******************************************************************************
+ * ƥ
+ *****************************************************************************/
+#ifdef DEBUG_UploadItem
+#include "apr_general.h"
+
+#include <iomanip>
+
+void usage(const char *prog_name)
+{
+    cerr << "Usage: " << prog_name << " <INPUT>" << endl;
+}
+
+void print_offset(const char *name, unsigned int offset, unsigned int expected) {
+    cout << "    ";
+    cout.width(27);
+    cout.setf(ios::left, ios::adjustfield);
+    cout << name << ": ";
+    cout.width(3);
+    cout.setf(ios::right, ios::adjustfield);
+    cout << offset << endl;
+
+    if (offset != expected) {
+        cerr << "Error: expected " << expected << ", but actual " << offset << endl;
+    }
+}
+
+int main(int argc, const char * const *argv)
+{
+    apr_pool_t *pool;
+    unsigned int offset;
+
+    apr_app_initialize(&argc, &argv, NULL);
+    apr_pool_create(&pool, NULL);
+
+    cout << "* Cheack the struct size"<< endl;
+    cout << "    sizeof(UploadItem::header) : ";
+    cout.width(3);
+    cout.setf(ios::right, ios::adjustfield);
+    cout << sizeof(UploadItem::header) << endl;
+    cout << "    ITEM_HEADER_SIZE           : ";
+    cout.width(3);
+    cout.setf(ios::right, ios::adjustfield);
+    cout << UploadItem::ITEM_HEADER_SIZE << endl;
+    if (sizeof(UploadItem::header) != UploadItem::ITEM_HEADER_SIZE) {
+        cerr << "Error: sizeof(UploadItem::header) != ITEM_HEADER_SIZE" << endl;
+    }
+    cout << endl;
+
+    // ǡθߴͤʤ饢饤ȤϤȤ
+    // ɡȤꤢ֡
+    //
+    // ʲǤϡPentium 4 3.06GHzLinux 2.6, GCC 3.3.5 Ǥδͤ
+    // ӤƤޤ
+
+    cout << "* Check the member offset" << endl;
+
+    offset = 0;
+
+    print_offset("identifier",
+                 offsetof(UploadItem::header, identifier),
+                 offset);
+    offset += (sizeof(PACKAGE_NAME)/4 + 1)*4;
+
+    print_offset("version",
+                 offsetof(UploadItem::header, version),
+                 offset);
+    offset += UploadItem::MAX_VERSION_LENGTH;
+
+    print_offset("file_size",
+                 offsetof(UploadItem::header, file_size),
+                 offset);
+    offset += 4;
+
+    print_offset("time",
+                 offsetof(UploadItem::header, time),
+                 offset);
+    offset += 8;
+
+    print_offset("file_mime",
+                 offsetof(UploadItem::header, file_mime),
+                 offset);
+    offset += UploadItem::MAX_FILE_MIME_LENGTH;
+
+    print_offset("file_name",
+                 offsetof(UploadItem::header, file_name),
+                 offset);
+    offset += UploadItem::MAX_FILE_NAME_LENGTH;
+
+    print_offset("remove_pass",
+                 offsetof(UploadItem::header, remove_pass),
+                 offset);
+    offset += UploadItem::MAX_REMOVE_PASS_LENGTH;
+
+    print_offset("download_pass",
+                 offsetof(UploadItem::header, download_pass),
+                 offset);
+    offset += UploadItem::MAX_DOWNLOAD_PASS_LENGTH;
+
+    print_offset("comment",
+                 offsetof(UploadItem::header, comment),
+                 offset);
+
+    apr_terminate();
+
+    return EXIT_SUCCESS;
+}
+#endif
+
 // Local Variables:
 // mode: c++
 // buffer-file-coding-system: euc-japan-dos
