@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.cpp 593 2005-09-05 14:41:59Z svn $
+ * $Id: UploadItemList.cpp 665 2005-09-09 00:56:59Z svn $
  *****************************************************************************/
 
 #include "UploadItemList.h"
@@ -136,6 +136,8 @@ void UploadItemList::remove(const char *file_path, const char *password)
 {
     item_iterator i;
 
+    load_file();
+
     for (i = begin(); i != end(); i++) {
         if (strcmp((*i)->file_path, file_path) == 0) {
             break;
@@ -414,6 +416,10 @@ void UploadItemList::load_thumb()
 
 void UploadItemList::add_new(item_info *info)
 {
+    bool is_load_by_cache;
+
+    is_load_by_cache = load_file();
+
 #ifdef MAKE_THUMBNAIL
     try {
         twriter_.write(info->file_path);
@@ -424,7 +430,9 @@ void UploadItemList::add_new(item_info *info)
     }
 #endif
 
-    add(info);
+    if (is_load_by_cache) {
+        add(info);
+    }
 
     while (ilist_.size() > total_number_limit_) {
         remove(ilist_.back());
