@@ -24,11 +24,12 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemReader.cpp 469 2005-07-19 00:23:53Z svn $
+ * $Id: UploadItemReader.cpp 551 2005-09-01 07:38:16Z svn $
  *****************************************************************************/
 
 #include "UploadItemReader.h"
 #include "Auxiliary.h"
+#include "Misc.h"
 
 #define APR_WANT_STRFUNC
 #include "apr_want.h"
@@ -72,7 +73,8 @@ UploadItem::header *UploadItemReader::read(const char *file_name,
         throw "åץɥե򳫤ޤǤ";
     }
 
-    header = reinterpret_cast<UploadItem::header *>(apr_pcalloc(pool, sizeof(UploadItem::header)));
+    APR_PCALLOC(header, UploadItem::header *, pool, sizeof(UploadItem::header));
+
     size = sizeof(UploadItem::header);
     if ((apr_file_read(*file, header, &size) != APR_SUCCESS) ||
         (size != sizeof(UploadItem::header))) {
@@ -83,9 +85,9 @@ UploadItem::header *UploadItemReader::read(const char *file_name,
         throw "̤ΤηΥեǤ";
     }
 
-    offset = UploadItem::ITEM_HEADER_SIZE;
+    offset = sizeof(UploadItem::header);
     if ((apr_file_seek(*file, APR_SET, &offset) != APR_SUCCESS) ||
-        (static_cast<apr_size_t>(offset) != UploadItem::ITEM_HEADER_SIZE)) {
+        (static_cast<apr_size_t>(offset) != sizeof(UploadItem::header))) {
         throw "ե seek ˼Ԥޤ";
     }
 
@@ -152,7 +154,7 @@ int main(int argc, const char * const *argv)
         }
 
         UploadParser parser (FILE_DIR, 10*1024*1024, 32*1024*1024, 5,
-                             UploadItem::ITEM_HEADER_SIZE);
+                             sizeof(UploadItem::header));
 
         auto_ptr<UploadParser::query_map>
             qmap(parser.parse(pool, fd,
