@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemWriter.cpp 441 2005-07-08 20:14:06Z svn $
+ * $Id: UploadItemWriter.cpp 551 2005-09-01 07:38:16Z svn $
  *****************************************************************************/
 
 #include "UploadItemWriter.h"
@@ -165,7 +165,7 @@ int main(int argc, const char * const *argv)
         }
 
         UploadParser parser(FILE_DIR, 10*1024*1024, 32*1024*1024, 5,
-                            UploadItem::ITEM_HEADER_SIZE);
+                            sizeof(UploadItem::header));
 
         auto_ptr<UploadParser::query_map>
             qmap(parser.parse(pool, fd,
