@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.cpp 593 2005-09-05 14:41:59Z svn $
+ * $Id: UploaderConfig.cpp 643 2005-09-07 23:36:20Z svn $
  *****************************************************************************/
 
 #include "mod_uploader_data.h"
@@ -67,6 +67,7 @@ UploaderConfig::UploaderConfig()
       tmp_dir(NULL),
       magick_dir(NULL),
       view_tmpl_path(NULL),
+      progress_tmpl_path(NULL),
       download_tmpl_path(NULL),
       thumb_tmpl_path(NULL),
       error_tmpl_path(NULL),
@@ -80,6 +81,8 @@ UploaderConfig::UploaderConfig()
       uparser(NULL),
       view_tmpl_(NULL),
       view_tmpl_pool_(NULL),
+      progress_tmpl_(NULL),
+      progress_tmpl_pool_(NULL),
       download_tmpl_(NULL),
       download_tmpl_pool_(NULL),
       thumb_tmpl_(NULL),
@@ -111,7 +114,7 @@ void UploaderConfig::init(request_rec *r)
     // ϼΥɤ mod_uploader.cpp ֤ɡѥեޥ
     // ͤƤ夭ޤ
     glock_ = (static_cast<sconfig *>(ap_get_module_config(r->server->module_config,
-                                                          &uploader_module)))->glock;
+                                                          &uploader_module)))->upload_lock;
 
     global_lock();
     try {
@@ -131,6 +134,7 @@ void UploaderConfig::finalize()
     DELETE(texecutor);
     DELETE(item_list);
     DELETE(view_tmpl_);
+    DELETE(progress_tmpl_);
     DELETE(download_tmpl_);
 #ifdef MAKE_THUMBNAIL
     DELETE(thumb_tmpl_);
@@ -139,6 +143,7 @@ void UploaderConfig::finalize()
 
     DESTROY(list_pool_);
     DESTROY(view_tmpl_pool_);
+    DESTROY(progress_tmpl_pool_);
     DESTROY(download_tmpl_pool_);
 #ifdef MAKE_THUMBNAIL
     DESTROY(thumb_tmpl_pool_);
@@ -155,6 +160,15 @@ UploaderConfig::page_template *UploaderConfig::get_view_template(apr_pool_t *poo
     return view_tmpl_;
 }
 
+UploaderConfig::page_template *UploaderConfig::get_progress_template(apr_pool_t *pool)
+{
+    if (UNLIKELY(get_mtime(pool, progress_tmpl_path) > progress_tmpl_->mtime)) {
+        load_template(pool, &progress_tmpl_pool_, progress_tmpl_path, progress_tmpl_);
+    }
+
+    return progress_tmpl_;
+}
+
 UploaderConfig::page_template *UploaderConfig::get_download_template(apr_pool_t *pool)
 {
     if (UNLIKELY(get_mtime(pool, download_tmpl_path) > download_tmpl_->mtime)) {
@@ -253,6 +267,7 @@ void UploaderConfig::exec_init()
     load_list();
 
     view_tmpl_      = new page_template();
+    progress_tmpl_  = new page_template();
     download_tmpl_  = new page_template();
 #ifdef MAKE_THUMBNAIL
     thumb_tmpl_     = new page_template();
@@ -277,6 +292,7 @@ void UploaderConfig::validate()
 #endif
     if (tmp_dir             == NULL) throw "TmpDirectory is not specified.";
     if (view_tmpl_path      == NULL) throw "ViewTemplateFile is not specified.";
+    if (progress_tmpl_path  == NULL) throw "ProgressTemplateFile is not specified.";
     if (download_tmpl_path  == NULL) throw "DownloadTemplateFile is not specified.";
     if (thumb_tmpl_path     == NULL) throw "ThumbTemplateFile is not specified.";
     if (error_tmpl_path     == NULL) throw "ErrorTemplateFile is not specified.";
