@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: mod_uploader.cpp 626 2005-09-06 22:39:53Z svn $
+ * $Id: mod_uploader.cpp 662 2005-09-08 17:20:32Z svn $
  *****************************************************************************/
 
 #define __STDC_CONSTANT_MACROS
@@ -71,6 +71,8 @@ static int command_handler(request_rec *r, uconfig *config, const char *arg);
 static int view(request_rec *r, uconfig *config, const char *arg);
 static int rss(request_rec *r, uconfig *config, const char *arg);
 static int upload(request_rec *r, uconfig *config, const char *arg);
+static int progress(request_rec *r, uconfig *config, const char *arg);
+static int progress_data(request_rec *r, uconfig *config, const char *arg);
 static int download(request_rec *r, uconfig *config, const char *arg);
 static int remove(request_rec *r, uconfig *config, const char *arg);
 static int error(request_rec *r, uconfig *config, const char *error);
@@ -86,22 +88,39 @@ static variable_map *get_view_vmap(apr_pool_t *pool, UploaderConfig *config,
                                    page_template *tmpl, apr_size_t page);
 static variable_map *get_download_vmap(apr_pool_t *pool, UploaderConfig *config,
                                        page_template *tmpl, UploadItem::header *header);
+static variable_map *get_progress_vmap(apr_pool_t *pool, UploaderConfig *config,
+                                       page_template *tmpl);
 #ifdef MAKE_THUMBNAIL
 static int thumbnail(request_rec *r, uconfig *config, const char *arg);
 static variable_map *get_thumb_vmap(apr_pool_t *pool, UploaderConfig *config,
                                     page_template *tmpl, apr_size_t page);
 #endif
 static apr_size_t get_page(request_rec *r);
-
-static const char *get_poster_address(request_rec *r);
-static bool is_poster_list_contain(request_rec *r, const char *address);
-static void add_poster_list(request_rec *r, const char *address);
-static int poster_compare(const poster *a, const poster *b);
-
+static apr_size_t get_upload_id(request_rec *r);
 static const char *get_name_encoding(request_rec *r);
 
+static apr_global_mutex_t *get_progress_lock(request_rec *r);
+static pprogress *get_progress(request_rec *r, apr_size_t upload_id);
+static pprogress *add_progress_list(request_rec *r, apr_size_t upload_id);
+static pprogress *get_progress_list(request_rec *r);
+
+static const char *get_client_address(request_rec *r);
+static bool is_poster_list_contain(request_rec *r, const char *address);
+static int poster_compare(const poster *a, const poster *b);
+static void add_poster_list(request_rec *r, const char *address);
+static poster *get_poster_list(request_rec *r);
+
+static apr_status_t create_lock(apr_pool_t *pool, apr_global_mutex_t **lock,
+                                const char *file_path, server_rec *s);
+static apr_status_t attach_shm(apr_pool_t *pool, apr_shm_t **shm_data, void **data,
+                               const char *file_path, server_rec *s);
+
 #define MATCH(str, pat) (strstr(str, pat) != 0)
 
+#define INFO(command, target) \
+    ap_log_rerror(APLOG_MARK, APLOG_INFO, 0, r, \
+                  "[" PACKAGE_NAME "] (%s) %s", command, target)
+
 #ifdef DEBUG
 #define SERROR(format, str) \
     fprintf(stderr, "[" PACKAGE_NAME "] " format, str); fputc('\n', stderr)
@@ -134,6 +153,10 @@ int command_handler(request_rec *r, uconfig *config, const char *arg)
         return rss(r, config, arg);
     } else if (strcmp(command, UPLOAD_COMMAND) == 0) {
         return upload(r, config, arg);
+    } else if (strcmp(command, PROGRESS_COMMAND) == 0) {
+        return progress(r, config, arg);
+    } else if (strcmp(command, PROGRESS_DATA_COMMAND) == 0) {
+        return progress_data(r, config, arg);
     } else if (strcmp(command, DOWNLOAD_COMMAND) == 0) {
         return download(r, config, arg);
     } else if (strcmp(command, REMOVE_COMMAND) == 0) {
@@ -277,6 +300,8 @@ int rss(request_rec *r, uconfig *config, const char *arg)
 int upload(request_rec *r, uconfig *config, const char *arg)
 {
     const char *address;
+    apr_size_t upload_id;
+    pprogress *progress;
     apr_status_t status;
 
     if (r->method_number != M_POST) {
@@ -289,19 +314,29 @@ int upload(request_rec *r, uconfig *config, const char *arg)
         return HTTP_NO_CONTENT;
     }
 
-    address = get_poster_address(r);
+    address = get_client_address(r);
     if (is_poster_list_contain(r, address)) {
         return error(r, config,
                      apr_psprintf(r->pool, "%u ô֤ϺƤǤޤ", POST_INTERVAL_SEC));
     }
 
+    upload_id = get_upload_id(r);
+    progress = add_progress_list(r, upload_id);
+
     try {
         UploadItem::header *header;
         const char *tmp_path;
         const char *file_name;
+        apr_size_t content_size;
+
+        content_size = static_cast<apr_size_t>(apr_atoi64(apr_table_get(r->headers_in,
+                                                                        "Content-Length")));
+        progress->total_size = content_size;
 
         auto_ptr<UploadParser::query_map>
-            qmap(config->uparser->parse(r->pool, r, apr_table_get(r->headers_in, "Content-Type")));
+            qmap(config->uparser->parse(r->pool, r,
+                                        apr_table_get(r->headers_in, "Content-Type"),
+                                        content_size, progress));
 
         try {
             header = UploadItemCreator::create_header(r->pool, qmap.get(), &tmp_path);
@@ -325,12 +360,68 @@ int upload(request_rec *r, uconfig *config, const char *arg)
             throw;
         }
 
+        INFO("upload", file_name);
+
+        progress->end_time = apr_time_now();
+
         return redirect_top(r);
     } catch(const char *message) {
+        progress->end_time = apr_time_now();
+
         return error(r, config, message);
     }
 }
 
+int progress(request_rec *r, uconfig *config, const char *arg)
+{
+    try {
+        page_template *tmpl = config->get_progress_template(r->pool);
+
+        auto_ptr<variable_map> vmap(get_progress_vmap(r->pool, config, tmpl));
+
+        ap_set_content_type(r, "text/html");
+        config->texecutor->exec(r->pool, r, tmpl->node, tmpl->imap, vmap.get());
+
+        return OK;
+    } catch(const char *message) {
+        ap_rputs("<div class=\"warning\">", r);
+        ap_rputs(message, r);
+        ap_rputs("</div>", r);
+
+        return OK;
+    }
+}
+
+int progress_data(request_rec *r, uconfig *config, const char *arg)
+{
+    apr_size_t upload_id;
+    pprogress *progress;
+
+    upload_id = get_upload_id(r);
+
+    ap_update_mtime(r, apr_time_now());
+
+    // upload_id  0 λϥ顼
+    if (upload_id == 0) {
+        ap_rputs("e", r);
+        return OK;
+    }
+
+    progress = get_progress(r, upload_id);
+
+    if (progress != get_progress_list(r)) {
+        ap_rprintf(r,
+                   "s %" APR_SIZE_T_FMT " %" APR_SIZE_T_FMT,
+                   progress->total_size,
+                   progress->read_size);
+
+        return OK;
+    }
+
+    ap_rputs("u", r);
+    return OK;
+}
+
 int download(request_rec *r, uconfig *config, const char *arg)
 {
     const char *name;
@@ -440,23 +531,25 @@ int remove(request_rec *r, uconfig *config, const char *arg)
     }
 
     try {
-        const char *file;
+        const char *file_name;
         const char *password;
 
         ctable = get_command_table(r);
 
-        file = apr_table_get(ctable, UploadItem::FILE_PARAM);
+        file_name = apr_table_get(ctable, UploadItem::FILE_PARAM);
         password = apr_table_get(ctable, UploadItem::REMOVE_PASS_PARAM);
 
-        if ((file == NULL) || (password == NULL)) {
+        if ((file_name == NULL) || (password == NULL)) {
             return error(r, config, "եޤϥѥɤꤵƤޤ");
         }
 
         config->gwrite_lock();
         try {
-            config->item_list->remove(file, password);
+            config->item_list->remove(file_name, password);
             config->remove_item_number++;
             config->gwrite_unlock();
+
+            INFO("remove", file_name);
         } catch(const char *) {
             config->gwrite_unlock();
             throw;
@@ -590,6 +683,17 @@ variable_map *get_view_vmap(apr_pool_t *pool, UploaderConfig *config,
 
     vmap = new variable_map(tmpl->imap->size()+SYSTEM_KEY_NUMBER, NULL);
 
+    page_number = config->item_list->empty()
+        ? 1
+        : (config->item_list->size()-1)/config->per_page_item_number + 1;
+
+    if (page > page_number) {
+        page = page_number;
+    }
+
+    ident_id = TemplateExecutor::get_ident_id(tmpl->imap, PAGE_NUMBER_KEY);
+    vmap->at(ident_id) = create_variable(pool, static_cast<int>(page_number));
+
     ident_id = TemplateExecutor::get_ident_id(tmpl->imap, FILE_LIST_KEY);
     vmap->at(ident_id) = config->item_list->to_varray(pool,
                                                       (page-1)*config->per_page_item_number,
@@ -598,12 +702,6 @@ variable_map *get_view_vmap(apr_pool_t *pool, UploaderConfig *config,
     ident_id = TemplateExecutor::get_ident_id(tmpl->imap, CURRENT_PAGE_KEY);
     vmap->at(ident_id) = create_variable(pool, static_cast<int>(page));
 
-    page_number = config->item_list->empty()
-        ? 1
-        : (config->item_list->size()-1)/config->per_page_item_number + 1;
-    ident_id = TemplateExecutor::get_ident_id(tmpl->imap, PAGE_NUMBER_KEY);
-    vmap->at(ident_id) = create_variable(pool, static_cast<int>(page_number));
-
     ident_id = TemplateExecutor::get_ident_id(tmpl->imap, TOTAL_FILE_SIZE_KEY);
     vmap->at(ident_id) = create_variable(pool,
                                          size_str(pool, config->item_list->get_total_file_size()));
@@ -612,17 +710,27 @@ variable_map *get_view_vmap(apr_pool_t *pool, UploaderConfig *config,
     vmap->at(ident_id) = create_variable(pool,
                                          size_str(pool, config->item_list->get_total_file_size()));
 
-     ident_id = TemplateExecutor::get_ident_id(tmpl->imap, TOTAL_FILE_NUMBER_KEY);
-     vmap->at(ident_id) = create_variable(pool,
-                                          comma_str(pool, config->item_list->size()));
+    ident_id = TemplateExecutor::get_ident_id(tmpl->imap, TOTAL_FILE_NUMBER_KEY);
+    vmap->at(ident_id) = create_variable(pool,
+                                         comma_str(pool, config->item_list->size()));
 
-     ident_id = TemplateExecutor::get_ident_id(tmpl->imap, MAX_FILE_SIZE_KEY);
-     vmap->at(ident_id) = create_variable(pool,
-                                          size_str(pool, config->max_file_size));
+    ident_id = TemplateExecutor::get_ident_id(tmpl->imap, MAX_FILE_SIZE_KEY);
+    vmap->at(ident_id) = create_variable(pool,
+                                         size_str(pool, config->max_file_size));
 
-     ident_id = TemplateExecutor::get_ident_id(tmpl->imap, TOTAL_FILE_SIZE_LIMIT_KEY);
-     vmap->at(ident_id) = create_variable(pool,
-                                          size_str(pool, config->total_file_size_limit));
+    ident_id = TemplateExecutor::get_ident_id(tmpl->imap, TOTAL_FILE_SIZE_LIMIT_KEY);
+    vmap->at(ident_id) = create_variable(pool,
+                                         size_str(pool, config->total_file_size_limit));
+
+    return vmap;
+}
+
+variable_map *get_progress_vmap(apr_pool_t *pool, UploaderConfig *config,
+                                page_template *tmpl)
+{
+    variable_map *vmap;
+
+    vmap = new variable_map(tmpl->imap->size()+SYSTEM_KEY_NUMBER, NULL);
 
     return vmap;
 }
@@ -652,6 +760,17 @@ variable_map *get_thumb_vmap(apr_pool_t *pool, UploaderConfig *config,
 
     vmap = new variable_map(tmpl->imap->size()+SYSTEM_KEY_NUMBER, NULL);
 
+    page_number = (config->item_list->get_thumb_size() == 0)
+        ? 1
+        : (config->item_list->get_thumb_size()-1)/config->per_page_item_number + 1;
+
+    if (page > page_number) {
+        page = page_number;
+    }
+
+    ident_id = TemplateExecutor::get_ident_id(tmpl->imap, PAGE_NUMBER_KEY);
+    vmap->at(ident_id) = create_variable(pool, static_cast<int>(page_number));
+
     ident_id = TemplateExecutor::get_ident_id(tmpl->imap, THUMB_LIST_KEY);
     vmap->at(ident_id) = config->item_list->to_thumb_varray(pool,
                                                             (page-1)*config->per_page_item_number,
@@ -660,12 +779,6 @@ variable_map *get_thumb_vmap(apr_pool_t *pool, UploaderConfig *config,
     ident_id = TemplateExecutor::get_ident_id(tmpl->imap, CURRENT_PAGE_KEY);
     vmap->at(ident_id) = create_variable(pool, static_cast<int>(page));
 
-    page_number = (config->item_list->get_thumb_size() == 0)
-        ? 1
-        : (config->item_list->get_thumb_size()-1)/config->per_page_item_number + 1;
-    ident_id = TemplateExecutor::get_ident_id(tmpl->imap, PAGE_NUMBER_KEY);
-    vmap->at(ident_id) = create_variable(pool, static_cast<int>(page_number));
-
     ident_id = TemplateExecutor::get_ident_id(tmpl->imap, THUMB_NUMBER_KEY);
     vmap->at(ident_id) = create_variable(pool,
                                          comma_str(pool, config->item_list->get_thumb_size()));
@@ -676,87 +789,32 @@ variable_map *get_thumb_vmap(apr_pool_t *pool, UploaderConfig *config,
 
 apr_size_t get_page(request_rec *r)
 {
-    int page = 1;
-    const char *args = r->args;
+    apr_size_t page;
+    const char *args;
+
+    page = 1;
+    args = r->args;
 
     if (args != NULL) {
-        page = atoi(args);
-
-        if (page < 0) {
-            page = 0;
-        }
+        page = static_cast<apr_size_t>(atoi(args));
     }
 
-    return static_cast<apr_size_t>(page);
+    return page;
 }
 
-const char *get_poster_address(request_rec *r)
+apr_size_t get_upload_id(request_rec *r)
 {
-    char *address = "";
+    apr_size_t upload_id;
+    const char *args;
 
-    apr_sockaddr_ip_get(&address, r->connection->remote_addr);
+    upload_id = 0;
+    args = r->args;
 
-    return address;
-}
-
-bool is_poster_list_contain(request_rec *r, const char *address)
-{
-    sconfig *config;
-    apr_time_t now;
-    apr_size_t i;
-
-    config = static_cast<sconfig *>(ap_get_module_config(r->server->module_config,
-                                                         &uploader_module));
-
-    now = apr_time_now();
-    for (i = 0; i < POSTER_HISTORY_NUMBER; i++) {
-        if ((now - config->poster_list[i].time) > (POST_INTERVAL_SEC*APR_USEC_PER_SEC)) {
-            break;
-        }
-
-        if (strcmp(config->poster_list[i].address, address) == 0) {
-            return true;
-        }
+    if (args != NULL) {
+        upload_id = static_cast<apr_size_t>(apr_atoi64(args));
     }
 
-    return false;
-}
-
-int poster_compare(const poster *a, const poster *b)
-{
-    return b->time > a->time;
-}
-
-void add_poster_list(request_rec *r, const char *address)
-{
-    sconfig *config;
-    apr_time_t now;
-    apr_size_t i, j;
-
-    config = static_cast<sconfig *>(ap_get_module_config(r->server->module_config,
-                                                         &uploader_module));
-
-    now = apr_time_now();
-    for (i = 0; i < POSTER_HISTORY_NUMBER; i++) {
-        if ((now - config->poster_list[i].time) > (POST_INTERVAL_SEC*APR_USEC_PER_SEC)) {
-            break;
-        }
-    }
-
-    if (i == POSTER_HISTORY_NUMBER) {
-        i--;
-    }
-    config->poster_list[i].time = now;
-    strncpy(config->poster_list[i].address, address, sizeof(config->poster_list[i].address));
-    j = i;
-
-    while (++i < POSTER_HISTORY_NUMBER) {
-        config->poster_list[i].time = 0;
-    }
-
-    // ɬ׺¤ϰϤȤʤ
-    qsort(config->poster_list, j + 1, sizeof(poster),
-          reinterpret_cast<int(*)(const void *, const void *)>(poster_compare));
+    return upload_id;
 }
 
 const char *get_name_encoding(request_rec *r)
@@ -774,6 +832,244 @@ const char *get_name_encoding(request_rec *r)
     }
 }
 
+apr_global_mutex_t *get_progress_lock(request_rec *r)
+{
+    return static_cast<sconfig *>(ap_get_module_config(r->server->module_config,
+                                                        &uploader_module))->progress_lock;
+}
+
+pprogress *get_progress(request_rec *r, apr_size_t upload_id)
+{
+    pprogress *progress_list;
+    apr_size_t i;
+
+    progress_list = get_progress_list(r);
+
+    if (upload_id == 0) {
+        return &progress_list[0];
+    }
+
+    for (i = 1; i < PROGRESS_LIST_NUMBER; i++) {
+        if (progress_list[i].upload_id == upload_id) {
+            return &progress_list[i];
+        }
+    }
+
+    return &progress_list[0];
+}
+
+pprogress *add_progress_list(request_rec *r, apr_size_t upload_id)
+{
+    pprogress *progress_list;
+    apr_global_mutex_t *lock;
+    apr_time_t now;
+    apr_size_t i;
+
+    progress_list = get_progress_list(r);
+
+    if (upload_id == 0) {
+        return &progress_list[0];
+    }
+
+    lock = get_progress_lock(r);
+    if (apr_global_mutex_lock(lock) != APR_SUCCESS) {
+        return &progress_list[0];
+    }
+
+    now = apr_time_now();
+
+    // ȥξ
+    // progress_list[i].end_time == 0        : ̤
+    // progress_list[i].end_time == 1        : (åץ)
+    // progress_list[i].end_time == ʳ : (åץɴλ)
+
+    // Ʊ upload_id 뤫åĤĸŤȥ
+    for (i = 1; i < PROGRESS_LIST_NUMBER; i++) {
+        if (progress_list[i].end_time == 0) {
+            continue;
+        }
+
+        if ((progress_list[i].end_time != 1) &&
+            ((now - progress_list[i].end_time) > (PROGRESS_HOLD_SEC*APR_USEC_PER_SEC))) {
+            progress_list[i].upload_id = 0;
+            progress_list[i].end_time = 0;
+        } else if (progress_list[i].upload_id == upload_id) {
+            apr_global_mutex_unlock(lock);
+
+            return &progress_list[0];
+        }
+    }
+
+    for (i = 1; i < PROGRESS_LIST_NUMBER; i++) {
+        if (progress_list[i].end_time == 0) {
+            progress_list[i].upload_id  = upload_id;
+            progress_list[i].total_size = 0;
+            progress_list[i].read_size  = 0;
+            progress_list[i].end_time   = 1;
+
+            apr_global_mutex_unlock(lock);
+
+            return &progress_list[i];
+        }
+    }
+
+    apr_global_mutex_unlock(lock);
+
+    return &progress_list[0];
+}
+
+pprogress *get_progress_list(request_rec *r)
+{
+    return static_cast<sconfig *>(ap_get_module_config(r->server->module_config,
+                                                       &uploader_module))->progress_list;
+}
+
+const char *get_client_address(request_rec *r)
+{
+    char *address = "";
+
+    apr_sockaddr_ip_get(&address, r->connection->remote_addr);
+
+    return address;
+}
+
+bool is_poster_list_contain(request_rec *r, const char *address)
+{
+    poster *poster_list;
+    apr_time_t now;
+    apr_size_t i;
+
+    poster_list = get_poster_list(r);
+
+    now = apr_time_now();
+    for (i = 0; i < POSTER_LIST_NUMBER; i++) {
+        if ((now - poster_list[i].time) > (POST_INTERVAL_SEC*APR_USEC_PER_SEC)) {
+            break;
+        }
+
+        if (strcmp(poster_list[i].address, address) == 0) {
+            return true;
+        }
+    }
+
+    return false;
+}
+
+int poster_compare(const poster *a, const poster *b)
+{
+    return b->time > a->time;
+}
+
+void add_poster_list(request_rec *r, const char *address)
+{
+    poster *poster_list;
+    apr_time_t now;
+    apr_size_t i, j;
+
+    poster_list = get_poster_list(r);
+
+    now = apr_time_now();
+    for (i = 0; i < POSTER_LIST_NUMBER; i++) {
+        if ((now - poster_list[i].time) > (POST_INTERVAL_SEC*APR_USEC_PER_SEC)) {
+            break;
+        }
+    }
+
+    if (i == POSTER_LIST_NUMBER) {
+        i--;
+    }
+    poster_list[i].time = now;
+    strncpy(poster_list[i].address, address, sizeof(poster_list[i].address));
+    j = i;
+
+    while (++i < POSTER_LIST_NUMBER) {
+        poster_list[i].time = 0;
+    }
+
+    // ɬ׺¤ϰϤȤʤ
+    qsort(poster_list, j + 1, sizeof(poster),
+          reinterpret_cast<int(*)(const void *, const void *)>(poster_compare));
+}
+
+poster *get_poster_list(request_rec *r)
+{
+    return static_cast<sconfig *>(ap_get_module_config(r->server->module_config,
+                                                       &uploader_module))->poster_list;
+}
+
+apr_status_t create_lock(apr_pool_t *pool, apr_global_mutex_t **lock,
+                         const char *file_path, server_rec *s)
+{
+    apr_status_t status;
+    char error[MAX_ERROR_MESSAGE];
+
+    status = apr_global_mutex_create(lock, file_path, APR_LOCK_DEFAULT, pool);
+    if (status != APR_SUCCESS) {
+        SERROR("Can not create global mutex (%s).", file_path);
+        SERROR("(%s)", apr_strerror(status, error, sizeof(error)));
+
+        return HTTP_INTERNAL_SERVER_ERROR;
+    }
+
+#ifdef AP_NEED_SET_MUTEX_PERMS
+    status = unixd_set_global_mutex_perms(*lock);
+    if (status != APR_SUCCESS) {
+        SERROR("Can not set permissions on global mutex (%s).", file_path);
+        SERROR("(%s)", apr_strerror(status, error, sizeof(error)));
+
+        return HTTP_INTERNAL_SERVER_ERROR;
+    }
+#endif
+
+    return APR_SUCCESS;
+}
+
+apr_status_t create_shm(apr_pool_t *pool, apr_shm_t **shm_data, void **data,
+                        const char *file_path, apr_size_t size, server_rec *s)
+{
+    apr_status_t status;
+    char error[MAX_ERROR_MESSAGE];
+
+    // ޤϡAnonymous Shared Memory Ƥߤ롥
+    status = apr_shm_create(shm_data, size, NULL, pool);
+    if (status == APR_ENOTIMPL) {
+        status = apr_shm_create(shm_data, size, file_path, pool);
+    }
+    if (status != APR_SUCCESS) {
+        SERROR("Can not create shared segment file (%s).", file_path);
+        SERROR("(%s)", apr_strerror(status, error, sizeof(error)));
+
+        return status;
+    }
+
+    *data = apr_shm_baseaddr_get(*shm_data);
+    memset(*data, 0, size);
+
+    return APR_SUCCESS;
+}
+
+apr_status_t attach_shm(apr_pool_t *pool, apr_shm_t **shm_data, void **data,
+                        const char *file_path, server_rec *s)
+{
+    apr_status_t status;
+    char error[MAX_ERROR_MESSAGE];
+
+    if (*shm_data == NULL) {
+        status = apr_shm_attach(shm_data, file_path, pool);
+
+        if (status != APR_SUCCESS) {
+            SERROR("Can not attach to shared segment file (%s).", file_path);
+            SERROR("(%s)", apr_strerror(status, error, sizeof(error)));
+
+            return status;
+        }
+    }
+
+    *data = apr_shm_baseaddr_get(*shm_data);
+
+    return APR_SUCCESS;
+}
+
 extern "C" {
 static int uploader_handler(request_rec *r)
 {
@@ -805,6 +1101,10 @@ static apr_status_t finalize_server_config(void *data)
         apr_shm_destroy(config->poster_list_shm);
         config->poster_list_shm = NULL;
     }
+    if (config->progress_list_shm != NULL) {
+        apr_shm_destroy(config->progress_list_shm);
+        config->progress_list_shm = NULL;
+    }
 
     return APR_SUCCESS;
 }
@@ -828,12 +1128,17 @@ static void *create_server_config(apr_pool_t *p, server_rec *s)
 
     apr_temp_dir_get(&tmp_dir, p);
 
-    apr_filepath_merge(&(config->glock_path), tmp_dir, GLOCK_NAME,
+    apr_filepath_merge(&(config->upload_lock_path), tmp_dir, UPLOAD_LOCK_NAME,
+                       APR_FILEPATH_NOTABOVEROOT, p);
+    apr_filepath_merge(&(config->progress_lock_path), tmp_dir, PROGRESS_LOCK_NAME,
                        APR_FILEPATH_NOTABOVEROOT, p);
     apr_filepath_merge(&(config->poster_list_path), tmp_dir, POSTER_LIST_NAME,
                        APR_FILEPATH_NOTABOVEROOT, p);
+    apr_filepath_merge(&(config->progress_list_path), tmp_dir, PROGRESS_LIST_NAME,
+                       APR_FILEPATH_NOTABOVEROOT, p);
 
     config->poster_list_shm = NULL;
+    config->progress_list_shm = NULL;
 
     return config;
 }
@@ -855,8 +1160,6 @@ static int post_config(apr_pool_t *pconf, apr_pool_t *plog,
 {
     sconfig *config;
     void *user_data;
-    apr_status_t status;
-    char error[1024];
 
     apr_pool_userdata_get(&user_data, USER_DATA_KEY, s->process->pool);
     if (user_data == NULL) {
@@ -867,41 +1170,29 @@ static int post_config(apr_pool_t *pconf, apr_pool_t *plog,
 
     config = static_cast<sconfig *>(ap_get_module_config(s->module_config, &uploader_module));
 
-    status = apr_global_mutex_create(&(config->glock), config->glock_path,
-                                     APR_LOCK_DEFAULT, pconf);
-    if (status != APR_SUCCESS) {
-        SERROR("Can not create global mutex (%s).", config->glock_path);
-        SERROR("(%s)", apr_strerror(status, error, sizeof(error)));
-
+    if (create_lock(pconf, &(config->upload_lock), config->upload_lock_path,
+                    s) != APR_SUCCESS) {
         return HTTP_INTERNAL_SERVER_ERROR;
     }
 
-#ifdef AP_NEED_SET_MUTEX_PERMS
-    status = unixd_set_global_mutex_perms(config->glock);
-    if (status != APR_SUCCESS) {
-        SERROR("Can not set permissions on global mutex (%s).", config->poster_list_path);
-        SERROR("(%s)", apr_strerror(status, error, sizeof(error)));
-
-        return HTTP_INTERNAL_SERVER_ERROR;
-    }
-#endif
-
-    // ޤϡAnonymous Shared Memory Ƥߤ롥
-    status = apr_shm_create(&(config->poster_list_shm), sizeof(poster)*POSTER_HISTORY_NUMBER,
-                            NULL, pconf);
-    if (status == APR_ENOTIMPL) {
-        status = apr_shm_create(&(config->poster_list_shm), sizeof(poster)*POSTER_HISTORY_NUMBER,
-                                config->poster_list_path, pconf);
-    }
-    if (status != APR_SUCCESS) {
-        SERROR("Can not create shared segment file (%s).", config->poster_list_path);
-        SERROR("(%s)", apr_strerror(status, error, sizeof(error)));
-
+    if (create_lock(pconf, &(config->progress_lock), config->progress_lock_path,
+                    s) != APR_SUCCESS) {
         return HTTP_INTERNAL_SERVER_ERROR;
     }
 
-    config->poster_list = static_cast<poster *>(apr_shm_baseaddr_get(config->poster_list_shm));
-    memset(config->poster_list, 0, sizeof(poster)*POSTER_HISTORY_NUMBER);
+    if (create_shm(pconf, &(config->poster_list_shm),
+                   reinterpret_cast<void **>(&config->poster_list),
+                   config->poster_list_path, sizeof(poster)*POSTER_LIST_NUMBER,
+                   s) != APR_SUCCESS) {
+        return HTTP_INTERNAL_SERVER_ERROR;
+    }
+
+    if (create_shm(pconf, &(config->progress_list_shm),
+                   reinterpret_cast<void **>(&(config->progress_list)),
+                   config->progress_list_path, sizeof(pprogress)*PROGRESS_LIST_NUMBER,
+                   s) != APR_SUCCESS) {
+        return HTTP_INTERNAL_SERVER_ERROR;
+    }
 
     // windows Ǥ򤹤ȥӥ̾ѤäƤޤ餷
 #ifndef WIN32
@@ -919,23 +1210,24 @@ static void child_init(apr_pool_t *p, server_rec *s)
 
     config = static_cast<sconfig *>(ap_get_module_config(s->module_config, &uploader_module));
 
-    if (apr_global_mutex_child_init(&(config->glock),
-                                    config->glock_path, p) != APR_SUCCESS) {
-        SERROR("Can not attach to global mutex (%s).", config->glock_path);
+    if (apr_global_mutex_child_init(&(config->upload_lock),
+                                    config->upload_lock_path, p) != APR_SUCCESS) {
+        SERROR("Can not attach to global mutex (%s).", config->upload_lock_path);
 
         return;
     }
 
-    if (!config->poster_list_shm) {
-        if (apr_shm_attach(&(config->poster_list_shm), config->poster_list_path,
-                           p) != APR_SUCCESS) {
-            SERROR("Can not attach to shared segment file (%s).", config->poster_list_path);
-
-            return;
-        }
+    if (attach_shm(p, &(config->poster_list_shm),
+                   reinterpret_cast<void **>(&config->poster_list),
+                   config->poster_list_path, s) != APR_SUCCESS) {
+        return;
     }
 
-    config->poster_list = static_cast<poster *>(apr_shm_baseaddr_get(config->poster_list_shm));
+    if (attach_shm(p, &(config->progress_list_shm),
+                   reinterpret_cast<void **>(&config->progress_list),
+                   config->progress_list_path, s) != APR_SUCCESS) {
+        return;
+    }
 }
 
 static const char *set_url(cmd_parms *parms, void *mconfig, char *arg)
@@ -983,6 +1275,15 @@ static const char *set_view_tmpl_path(cmd_parms *parms, void *mconfig, char *arg
     return NULL;
 }
 
+static const char *set_progress_tmpl_path(cmd_parms *parms, void *mconfig, char *arg)
+{
+    uconfig *config = static_cast<uconfig *>(mconfig);
+
+    config->progress_tmpl_path = apr_pstrdup(parms->pool, arg);
+
+    return NULL;
+}
+
 static const char *set_download_tmpl_path(cmd_parms *parms, void *mconfig, char *arg)
 {
     uconfig *config = static_cast<uconfig *>(mconfig);
@@ -1062,6 +1363,9 @@ static const command_rec uploader_cmds[] = {
     AP_INIT_TAKE1(VIEW_TEMPLATE_FILE_PARAM,
                   reinterpret_cast<const char*(*)()>(set_view_tmpl_path), NULL,
                   ACCESS_CONF, "View Template File"),
+    AP_INIT_TAKE1(PROGRESS_TEMPLATE_FILE_PARAM,
+                  reinterpret_cast<const char*(*)()>(set_progress_tmpl_path), NULL,
+                  ACCESS_CONF, "Progress Template File"),
     AP_INIT_TAKE1(DOWNLOAD_TEMPLATE_FILE_PARAM,
                   reinterpret_cast<const char*(*)()>(set_download_tmpl_path), NULL,
                   ACCESS_CONF, "Download Template File"),
