@@ -17,10 +17,14 @@ sub new {
     my $class = shift;
     my $project = shift;
 
-    bless {
+    my $member = {
         project => $project,
         mech => WWW::Mechanize->new(),
-    }, $class;
+    };
+
+    $member->{'mech'}->agent_alias('Windows IE 6');
+
+    bless $member, $class;
 }
 
 sub login {
